==> resampledata_0.3.0.tar.gz: resampledata/R/data.R <==
#' Calories and alcohol content for ales and lagers.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Alelager"


#' Bangladesh
#'
#' The Bangladesh data is provided solely for illustrative purposes and to
#' enable statistical analysis.  Full data are available from the British
#' Geological Survey web site:
#' \url{http://www.bgs.ac.uk/arsenic/bphase2/datadownload.htm}.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Bangladesh"


#' Batters2005
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Batters2005"


#' Beer and hot wings consumption.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Beerwings"


#' Price of hardcover textbooks from mathematics and the natural sciences and
#' the social sciences.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"BookPrices"


#' Bushmeat in Ghana.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Bushmeat"


#' Bushmeat in Ghana.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Bushmeat2"


#' Prices of a sample of point-and-shoot digital cameras.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Cameras"


#' Information on various cereals.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Cereals"


#' Data on 23 Challenger flights.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Challenger"


#' Data on Marathon times.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"ChiMarathonMen"


#' Correlation Exercise A p.294
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"corrExerciseA"


#' Correlation Exercise B p.294
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"corrExerciseB"


#' Cuckoos
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Cuckoos"


#' Diving times in 2017
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Diving2017"


#' Random sample of 100 driver fatalities in 2009 in Pennsylvania.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Fatalities"


#' Mercury levels (parts per million) for 30 fish caught in lakes in Minnesota.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"FishMercury"


#' Information on 4029 United and American airlines departures from LGA during May and June 2009.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"FlightDelays"


#' Random sample of 40 baby girls born in Alaska and 40 baby girls born in Wyoming.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Girls2004"


#' Groceries.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Groceries"


#' Results from 2002 General Society Survey.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"GSS2002"


#' Results from 2006 General Society Survey.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"GSS2006"


#' Calorie information for a sample of brands of chocolate and vanilla ice cream.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"IceCream"


#' IL Boys
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"ILBoys"


#' Data on a sample of countries where female illiteracy is more that 5 percent.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Illiteracy"


#' Winning numbers for the daily games from May 5, 2010 through August 15, 2010.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Lottery"


#' manatees
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"manatees"


#' Math Anxiety
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"MathAnxiety"


#' Data on average CO2 levels (ppm) for the month of May from 1990 to 2010.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Maunaloa"


#' Measurements on water quality of 895 randomly selected wells in Minnesota.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"MnGroundwater"


#' Mobile Ads.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"MobileAds"


#' NASDAQ Data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Nasdaq"


#' NBA 2016-2017 data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"NBA1617"


#' Random sample of 1009 babies born in North Carolina during 2004.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"NCBirths2004"


#' 2012 Olympics Data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Olympics2012"


#' Data from the 2009 season for the baseball team of the Philadelphia Phillies.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Phillies2009"


#' Pitchers2005
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Pitchers2005"


#' Time between earthquakes (in days).
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Quakes"


#' Quetzal.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Quetzal"


#' Rangers/Twins 2016 Baseball Data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"RangersTwins2016"


#' Children's reading abilities.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Reading"


#' Recidivism data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Recidivism"


#' Salaries
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Salaries"


#' Sat2008
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Sat2008"


#' Service times (in minutes) for 174 customers at a college snack bar.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Service"


#' Skateboarding data
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Skateboard"


#' Scores from the short program and free skate for men's figure skating in the 2010 Olympics.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Skating2010"


#' Study of factors affecting the growth of the black spruce.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Spruce"


#' Starcraft
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Starcraft"


#' Data on male passengers on the Titanic.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Titanic"


#' Wind Speeds (m/s) from Carleton College Turbine.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Turbine"


#' TV
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"TV"


#' Random sample of 1587 babies born in Texas in 2004.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"TXBirths2004"


#' Random sample of repair times for 1664 ILEC and 23 CLEC customers.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Verizon"


#' Volleyball2009
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Volleyball2009"


#' Wafers
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"wafers"


#' Length and weight measurements for a sample of 60 walleye caught in Minnesota lakes.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Walleye"


#' Relationship between seedling growth and water table depth for a sample of seedlings.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
#' \itemize{
#'   \item
#' }
"Watertable"

==> resampledata_0.3.2.tar.gz: resampledata/R/data.R <==
#' Calories and alcohol content for ales and lagers.
#'
#' A data set containing 31 beers. The variables are as follows:
#'
#' @format A data frame with 31 rows and 4 variables:
"Alelager"


#' Bangladesh
#'
#' The Bangladesh data is provided solely for illustrative purposes and to
#' enable statistical analysis.  Full data are available from the British
#' Geological Survey web site:
#' \url{https://www2.bgs.ac.uk/groundwater/health/arsenic/Bangladesh/home.html}.
#'
#' A data set containing 271 ??. The variables are as follows:
#'
#' @format A data frame with 271 rows and 3 variables:
"Bangladesh"


#' Batters2005
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Batters2005"


#' Beer and hot wings consumption.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Beerwings"


#' Price of hardcover textbooks from mathematics and the natural sciences and
#' the social sciences.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"BookPrices"


#' Bushmeat in Ghana.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Bushmeat"


#' Bushmeat in Ghana.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Bushmeat2"


#' Prices of a sample of point-and-shoot digital cameras.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Cameras"


#' Information on various cereals.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Cereals"


#' Data on 23 Challenger flights.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Challenger"


#' Data on Marathon times.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"ChiMarathonMen"


#' Correlation Exercise A p.294
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"corrExerciseA"


#' Correlation Exercise B p.294
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"corrExerciseB"


#' Cuckoos
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Cuckoos"


#' Diving times in 2017
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Diving2017"


#' Random sample of 100 driver fatalities in 2009 in Pennsylvania.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Fatalities"


#' Mercury levels (parts per million) for 30 fish caught in lakes in Minnesota.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"FishMercury"


#' Information on 4029 United and American airlines departures from LGA during May and June 2009.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"FlightDelays"


#' Random sample of 40 baby girls born in Alaska and 40 baby girls born in Wyoming.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Girls2004"


#' Groceries.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Groceries"


#' Results from 2002 General Society Survey.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"GSS2002"


#' Results from 2006 General Society Survey.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"GSS2006"


#' Calorie information for a sample of brands of chocolate and vanilla ice cream.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"IceCream"


#' IL Boys
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"ILBoys"


#' Data on a sample of countries where female illiteracy is more that 5 percent.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Illiteracy"


#' Winning numbers for the daily games from May 5, 2010 through August 15, 2010.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Lottery"


#' manatees
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"manatees"


#' Math Anxiety
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"MathAnxiety"


#' Data on average CO2 levels (ppm) for the month of May from 1990 to 2010.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Maunaloa"


#' Measurements on water quality of 895 randomly selected wells in Minnesota.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"MnGroundwater"


#' Mobile Ads.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"MobileAds"


#' NASDAQ Data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Nasdaq"


#' NBA 2016-2017 data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"NBA1617"


#' Random sample of 1009 babies born in North Carolina during 2004.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"NCBirths2004"


#' 2012 Olympics Data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Olympics2012"


#' Data from the 2009 season for the baseball team of the Philadelphia Phillies.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Phillies2009"


#' Pitchers2005
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Pitchers2005"


#' Time between earthquakes (in days).
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Quakes"


#' Quetzal.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Quetzal"


#' Rangers/Twins 2016 Baseball Data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"RangersTwins2016"


#' Children's reading abilities.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Reading"


#' Recidivism data.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Recidivism"


#' Salaries
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Salaries"


#' Sat2008
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Sat2008"


#' Service times (in minutes) for 174 customers at a college snack bar.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Service"


#' Skateboarding data
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Skateboard"


#' Scores from the short program and free skate for men's figure skating in the 2010 Olympics.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Skating2010"


#' Study of factors affecting the growth of the black spruce.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Spruce"


#' Starcraft
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Starcraft"


#' Data on male passengers on the Titanic.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Titanic"


#' Wind Speeds (m/s) from Carleton College Turbine.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Turbine"


#' TV
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"TV"


#' Random sample of 1587 babies born in Texas in 2004.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"TXBirths2004"


#' Random sample of repair times for 1664 ILEC and 23 CLEC customers.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Verizon"


#' Volleyball2009
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Volleyball2009"


#' Wafers
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"wafers"


#' Length and weight measurements for a sample of 60 walleye caught in Minnesota lakes.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Walleye"


#' Relationship between seedling growth and water table depth for a sample of seedlings.
#'
#' A data set containing X. The variables are as follows:
#'
#' @format A data frame with X rows and Y variables:
"Watertable"
